we will have a few versions. let's call them version 1 (bare minimum), version 2 (basics) and version 3 (full feature)

version 1
there is only 1 table. it has 3 columns:
1. datetime
2. name
3. value

version 2
there are several tables (aka pockets). each has 4 columns:
1. datetime
2. name
3. value
4. comment

